"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainContext = void 0;
const cctp_1 = require("./protocols/cctp");
const ibc_1 = require("./protocols/ibc");
const tokenBridge_1 = require("./protocols/tokenBridge");
class ChainContext {
    config;
    chain;
    // Cached Protocol clients
    rpc;
    tokenBridge;
    autoTokenBridge;
    circleBridge;
    autoCircleBridge;
    ibcBridge;
    constructor(config) {
        this.config = config;
        this.chain = config.key;
    }
    getRpc() {
        this.rpc = this.rpc ? this.rpc : this.platform.getRpc(this.chain);
        return this.rpc;
    }
    // Get the number of decimals for a token
    async getDecimals(token) {
        return this.platform.getDecimals(this.chain, this.getRpc(), token);
    }
    // Get the balance of a token for a given address
    async getBalance(walletAddr, token) {
        return this.platform.getBalance(this.chain, await this.getRpc(), walletAddr, token);
    }
    async getCurrentBlock() {
        return this.platform.getCurrentBlock(this.getRpc());
    }
    // Get details about the transaction
    async parseTransaction(txid) {
        return this.platform.parseTransaction(this.chain, await this.getRpc(), txid);
    }
    // Send a transaction and wait for it to be confirmed
    async sendWait(stxns) {
        return this.platform.sendWait(this.chain, await this.getRpc(), stxns);
    }
    //
    // protocols
    //
    //
    supportsTokenBridge = () => (0, tokenBridge_1.supportsTokenBridge)(this.platform);
    async getTokenBridge() {
        if (!(0, tokenBridge_1.supportsTokenBridge)(this.platform))
            throw new Error("Platform does not support TokenBridge");
        this.tokenBridge = this.tokenBridge
            ? this.tokenBridge
            : await this.platform.getTokenBridge(await this.getRpc());
        return this.tokenBridge;
    }
    //
    supportsAutomaticTokenBridge = () => (0, tokenBridge_1.supportsAutomaticTokenBridge)(this.platform);
    async getAutomaticTokenBridge() {
        if (!(0, tokenBridge_1.supportsAutomaticTokenBridge)(this.platform))
            throw new Error("Platform does not support AutomaticTokenBridge");
        this.autoTokenBridge = this.autoTokenBridge
            ? this.autoTokenBridge
            : await this.platform.getAutomaticTokenBridge(await this.getRpc());
        return this.autoTokenBridge;
    }
    //
    supportsCircleBridge = () => (0, cctp_1.supportsCircleBridge)(this.platform);
    async getCircleBridge() {
        if (!(0, cctp_1.supportsCircleBridge)(this.platform))
            throw new Error("Platform does not support CircleBridge");
        this.circleBridge = this.circleBridge
            ? this.circleBridge
            : await this.platform.getCircleBridge(await this.getRpc());
        return this.circleBridge;
    }
    //
    supportsAutomaticCircleBridge = () => (0, cctp_1.supportsAutomaticCircleBridge)(this.platform);
    async getAutomaticCircleBridge() {
        if (!(0, cctp_1.supportsAutomaticCircleBridge)(this.platform))
            throw new Error("Platform does not support AutomaticCircleBridge");
        this.autoCircleBridge = this.autoCircleBridge
            ? this.autoCircleBridge
            : await this.platform.getAutomaticCircleBridge(await this.getRpc());
        return this.autoCircleBridge;
    }
    //
    supportsIbcBridge = () => (0, ibc_1.supportsIbcBridge)(this.platform);
    async getIbcBridge() {
        if (!(0, ibc_1.supportsIbcBridge)(this.platform))
            throw new Error("Platform does not support AutomaticCircleBridge");
        this.ibcBridge = this.ibcBridge
            ? this.ibcBridge
            : await this.platform.getIbcBridge(await this.getRpc());
        return this.ibcBridge;
    }
}
exports.ChainContext = ChainContext;
//# sourceMappingURL=chain.js.map