import { ChainName, Network, PlatformName } from "@wormhole-foundation/sdk-base";
import { WormholeMessageId } from "./attestation";
import { ChainContext } from "./chain";
import { RpcConnection } from "./rpc";
import { AnyAddress, Balances, ChainsConfig, TokenId, TxHash } from "./types";
import { SignedTx } from "./types";
export interface PlatformUtils<P extends PlatformName> {
    nativeTokenId(chain: ChainName): TokenId;
    isSupportedChain(chain: ChainName): boolean;
    isNativeTokenId(chain: ChainName, tokenId: TokenId): boolean;
    getDecimals(chain: ChainName, rpc: RpcConnection<P>, token: AnyAddress): Promise<bigint>;
    getBalance(chain: ChainName, rpc: RpcConnection<P>, walletAddr: string, token: AnyAddress): Promise<bigint | null>;
    getBalances(chain: ChainName, rpc: RpcConnection<P>, walletAddress: string, tokens: AnyAddress[]): Promise<Balances>;
    getCurrentBlock(rpc: RpcConnection<P>): Promise<number>;
    sendWait(chain: ChainName, rpc: RpcConnection<P>, stxns: SignedTx[]): Promise<TxHash[]>;
    chainFromRpc(rpc: RpcConnection<P>): Promise<[Network, ChainName]>;
}
export interface Platform<P extends PlatformName> extends PlatformUtils<P> {
    readonly platform: P;
    readonly conf: ChainsConfig;
    readonly network: Network;
    setConfig(network: Network, _conf?: ChainsConfig): Platform<P>;
    getChain(chain: ChainName): ChainContext<P>;
    getRpc(chain: ChainName): RpcConnection<P>;
    parseTransaction(chain: ChainName, rpc: RpcConnection<P>, txid: TxHash): Promise<WormholeMessageId[]>;
}
//# sourceMappingURL=platform.d.ts.map