import { Layout, LayoutToType, PlatformName } from "@wormhole-foundation/sdk-base";
import { ChainAddress } from "../address";
import { CircleMessageId } from "../attestation";
import "../payloads/connect";
import { RpcConnection } from "../rpc";
import { AnyAddress, TokenId } from "../types";
import { UnsignedTransaction } from "../unsignedTransaction";
export declare const circleMessageLayout: Layout;
export declare const deserializeCircleMessage: (data: Uint8Array) => [LayoutToType<typeof circleMessageLayout>, string];
export type CircleTransferMessage = {
    from: ChainAddress;
    to: ChainAddress;
    token: TokenId;
    amount: bigint;
    messageId: CircleMessageId;
};
export interface AutomaticCircleBridge<P extends PlatformName> {
    transfer(token: ChainAddress, sender: AnyAddress, recipient: ChainAddress, amount: bigint, nativeGas?: bigint): AsyncGenerator<UnsignedTransaction>;
}
export interface CircleBridge<P extends PlatformName> {
    redeem(sender: AnyAddress, message: string, attestation: string): AsyncGenerator<UnsignedTransaction>;
    transfer(token: ChainAddress, sender: AnyAddress, recipient: ChainAddress, amount: bigint): AsyncGenerator<UnsignedTransaction>;
    parseTransactionDetails(txid: string): Promise<CircleTransferMessage>;
}
export interface SupportsCircleBridge<P extends PlatformName> {
    getCircleBridge(rpc: RpcConnection<P>): Promise<CircleBridge<P>>;
}
export declare function supportsCircleBridge<P extends PlatformName>(thing: SupportsCircleBridge<P> | any): thing is SupportsCircleBridge<P>;
export interface SupportsAutomaticCircleBridge<P extends PlatformName> {
    getAutomaticCircleBridge(rpc: RpcConnection<P>): Promise<AutomaticCircleBridge<P>>;
}
export declare function supportsAutomaticCircleBridge<P extends PlatformName>(thing: SupportsAutomaticCircleBridge<P> | any): thing is SupportsAutomaticCircleBridge<P>;
//# sourceMappingURL=cctp.d.ts.map