"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.supportsAutomaticCircleBridge = exports.supportsCircleBridge = exports.deserializeCircleMessage = exports.circleMessageLayout = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const layout_items_1 = require("../layout-items");
require("../payloads/connect");
const utils_1 = require("../utils");
// https://developers.circle.com/stablecoin/docs/cctp-technical-reference#message
const circleBurnMessageLayout = [
    { name: "version", binary: "uint", size: 4 },
    { name: "burnToken", ...layout_items_1.universalAddressItem },
    { name: "mintRecipient", ...layout_items_1.universalAddressItem },
    { name: "amount", binary: "uint", size: 32 },
    { name: "messageSender", ...layout_items_1.universalAddressItem },
];
// TODO: convert domain to chain name?
exports.circleMessageLayout = [
    { name: "version", binary: "uint", size: 4 },
    { name: "sourceDomain", binary: "uint", size: 4 },
    { name: "destinationDomain", binary: "uint", size: 4 },
    { name: "nonce", binary: "uint", size: 8 },
    { name: "sender", ...layout_items_1.universalAddressItem },
    { name: "recipient", ...layout_items_1.universalAddressItem },
    { name: "destinationCaller", ...layout_items_1.universalAddressItem },
    // TODO: is this the only message body we'll get?
    { name: "payload", binary: "object", layout: circleBurnMessageLayout },
];
const deserializeCircleMessage = (data) => {
    const msg = (0, sdk_base_1.deserializeLayout)(exports.circleMessageLayout, data);
    const messsageHash = (0, sdk_base_1.uint8ArrayToHexByteString)((0, utils_1.keccak256)(data));
    return [msg, messsageHash];
};
exports.deserializeCircleMessage = deserializeCircleMessage;
function supportsCircleBridge(thing) {
    return typeof thing.getCircleBridge === "function";
}
exports.supportsCircleBridge = supportsCircleBridge;
function supportsAutomaticCircleBridge(thing) {
    return (typeof thing
        .getAutomaticCircleBridge === "function");
}
exports.supportsAutomaticCircleBridge = supportsAutomaticCircleBridge;
//# sourceMappingURL=cctp.js.map