"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UniversalAddress = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const address_1 = require("./address");
class UniversalAddress {
    static byteSize = 32;
    type = "Universal";
    address;
    constructor(address) {
        if (typeof address === "string") {
            if (!UniversalAddress.isValidAddress(address))
                throw new Error(`Invalid Wormhole address, expected ${UniversalAddress.byteSize}-byte ` +
                    `hex string but got ${address}`);
            this.address = (0, sdk_base_1.hexByteStringToUint8Array)(address);
        }
        else {
            this.address = address;
        }
    }
    toNative(platform) {
        return (0, address_1.toNative)(platform, this);
    }
    unwrap() {
        return this.address;
    }
    toString() {
        return (0, sdk_base_1.uint8ArrayToHexByteString)(this.address);
    }
    toUint8Array() {
        return this.address;
    }
    toUniversalAddress() {
        return this;
    }
    equals(other) {
        if (UniversalAddress.instanceof(other)) {
            return other.toString() === this.toString();
        }
        return false;
    }
    static isValidAddress(address) {
        return (0, sdk_base_1.isHexByteString)(address, UniversalAddress.byteSize);
    }
    static instanceof(address) {
        return address.type === "Universal";
    }
}
exports.UniversalAddress = UniversalAddress;
//# sourceMappingURL=universalAddress.js.map