import { ChainName, Network, PlatformName } from "@wormhole-foundation/sdk-base";
import { ChainContext, Platform, TxHash, RpcConnection, TokenId, AutomaticTokenBridge, TokenBridge, WormholeMessageId, CircleBridge, AutomaticCircleBridge, ChainsConfig, NativeAddress, UniversalAddress, AnyAddress, Balances } from "../..";
import { WormholeCore } from "../../protocols/core";
export declare function mockPlatformFactory<P extends PlatformName>(network: Network, p: P, config: ChainsConfig): Platform<P>;
export declare class MockPlatform<P extends PlatformName> implements Platform<P> {
    readonly platform: P;
    network: Network;
    conf: ChainsConfig;
    constructor(network: Network, conf: ChainsConfig);
    setConfig(network: Network, _conf: ChainsConfig): MockPlatform<P>;
    nativeTokenId(chain: ChainName): TokenId;
    isNativeTokenId(chain: ChainName, tokenId: TokenId): boolean;
    isSupportedChain(chain: ChainName): boolean;
    getDecimals(chain: ChainName, rpc: RpcConnection<P>, token: NativeAddress<P> | UniversalAddress | "native"): Promise<bigint>;
    getBalance(chain: ChainName, rpc: RpcConnection<P>, walletAddr: string, token: NativeAddress<P> | UniversalAddress | "native"): Promise<bigint | null>;
    getBalances(chain: ChainName, rpc: RpcConnection<PlatformName>, walletAddress: string, tokens: AnyAddress[]): Promise<Balances>;
    getChain(chain: ChainName): ChainContext<P>;
    getRpc(chain: ChainName): RpcConnection<P>;
    getCurrentBlock(rpc: any): Promise<number>;
    getWrappedAsset(chain: ChainName, rpc: RpcConnection<P>, token: TokenId): Promise<TokenId | null>;
    getTokenDecimals(rpc: RpcConnection<P>, token: TokenId): Promise<bigint>;
    getNativeBalance(rpc: RpcConnection<P>, walletAddr: string): Promise<bigint>;
    getTokenBalance(chain: ChainName, rpc: RpcConnection<P>, walletAddr: string, token: TokenId): Promise<bigint | null>;
    parseTransaction(chain: ChainName, rpc: RpcConnection<P>, txid: TxHash): Promise<WormholeMessageId[]>;
    chainFromRpc(rpc: RpcConnection<P>): Promise<[Network, ChainName]>;
    parseAddress(chain: ChainName, address: string): NativeAddress<P>;
    sendWait(chain: ChainName, rpc: RpcConnection<P>, stxns: any[]): Promise<TxHash[]>;
    getWormholeCore(rpc: RpcConnection<P>): Promise<WormholeCore<P>>;
    getTokenBridge(rpc: RpcConnection<P>): Promise<TokenBridge<P>>;
    getAutomaticTokenBridge(rpc: RpcConnection<P>): Promise<AutomaticTokenBridge<P>>;
    getCircleBridge(rpc: RpcConnection<P>): Promise<CircleBridge<P>>;
    getCircleRelayer(rpc: RpcConnection<P>): Promise<AutomaticCircleBridge<P>>;
    getAutomaticCircleBridge(rpc: RpcConnection<P>): Promise<AutomaticCircleBridge<P>>;
}
//# sourceMappingURL=platform.d.ts.map