import { toNative, nativeIsRegistered, } from "../..";
import { MockRpc } from "./rpc";
import { MockChain } from "./chain";
import { MockTokenBridge } from "./tokenBridge";
export function mockPlatformFactory(network, p, config) {
    class ConcreteMockPlatform extends MockPlatform {
        platform = p;
    }
    return new ConcreteMockPlatform(network, config);
}
// Note: don't use this directly, instead create a ConcreteMockPlatform with the
// mockPlatformFactory
export class MockPlatform {
    // @ts-ignore
    platform;
    network;
    conf;
    constructor(network, conf) {
        this.network = network;
        this.conf = conf;
    }
    setConfig(network, _conf) {
        this.network = network;
        this.conf = _conf;
        return this;
    }
    nativeTokenId(chain) {
        throw new Error("Method not implemented.");
    }
    isNativeTokenId(chain, tokenId) {
        throw new Error("Method not implemented.");
    }
    isSupportedChain(chain) {
        throw new Error("Method not implemented.");
    }
    getDecimals(chain, rpc, token) {
        throw new Error("Method not implemented.");
    }
    getBalance(chain, rpc, walletAddr, token) {
        throw new Error("Method not implemented.");
    }
    getBalances(chain, rpc, walletAddress, tokens) {
        throw new Error("method not implemented");
    }
    getChain(chain) {
        if (chain in this.conf)
            return new MockChain(this.conf[chain]);
        throw new Error("No configuration available for chain: " + chain);
    }
    getRpc(chain) {
        // @ts-ignore
        return new MockRpc(chain);
    }
    getCurrentBlock(rpc) {
        throw new Error("Method not implemented");
    }
    async getWrappedAsset(chain, rpc, token) {
        throw new Error("Method not implemented.");
    }
    async getTokenDecimals(rpc, token) {
        return 8n;
    }
    async getNativeBalance(rpc, walletAddr) {
        return 0n;
    }
    async getTokenBalance(chain, rpc, walletAddr, token) {
        return 10n;
    }
    async parseTransaction(chain, rpc, txid) {
        throw new Error("Method not implemented");
    }
    async chainFromRpc(rpc) {
        throw new Error("Not implemented");
    }
    parseAddress(chain, address) {
        if (!nativeIsRegistered(chain))
            throw new Error("Chain not registered");
        //@ts-ignore
        return toNative(chain, address).toUniversalAddress();
    }
    async sendWait(chain, rpc, stxns) {
        throw new Error("Method not implemented.");
    }
    async getWormholeCore(rpc) {
        throw new Error("Method not implemented.");
    }
    async getTokenBridge(rpc) {
        // @ts-ignore
        return new MockTokenBridge(rpc);
    }
    async getAutomaticTokenBridge(rpc) {
        throw new Error("Method not implemented.");
    }
    async getCircleBridge(rpc) {
        throw new Error("Method not implemented.");
    }
    async getCircleRelayer(rpc) {
        throw new Error("Method Not implemented.");
    }
    async getAutomaticCircleBridge(rpc) {
        throw new Error("Method not implemented.");
    }
}
//# sourceMappingURL=platform.js.map