import { hexByteStringToUint8Array, uint8ArrayToHexByteString, isHexByteString, } from "@wormhole-foundation/sdk-base";
import { toNative } from "./address";
export class UniversalAddress {
    static byteSize = 32;
    type = "Universal";
    address;
    constructor(address) {
        if (typeof address === "string") {
            if (!UniversalAddress.isValidAddress(address))
                throw new Error(`Invalid Wormhole address, expected ${UniversalAddress.byteSize}-byte ` +
                    `hex string but got ${address}`);
            this.address = hexByteStringToUint8Array(address);
        }
        else {
            this.address = address;
        }
    }
    toNative(platform) {
        return toNative(platform, this);
    }
    unwrap() {
        return this.address;
    }
    toString() {
        return uint8ArrayToHexByteString(this.address);
    }
    toUint8Array() {
        return this.address;
    }
    toUniversalAddress() {
        return this;
    }
    equals(other) {
        if (UniversalAddress.instanceof(other)) {
            return other.toString() === this.toString();
        }
        return false;
    }
    static isValidAddress(address) {
        return isHexByteString(address, UniversalAddress.byteSize);
    }
    static instanceof(address) {
        return address.type === "Universal";
    }
}
//# sourceMappingURL=universalAddress.js.map