"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.namedPayloads = exports.depositWithBytesPayload = exports.depositWithSizedLayoutPayload = void 0;
const layout_items_1 = require("../layout-items");
const vaa_1 = require("../vaa");
const depositWithPayloadBase = [
    (0, layout_items_1.payloadIdItem)(1),
    {
        name: "token",
        binary: "object",
        layout: [
            { name: "address", ...layout_items_1.universalAddressItem },
            { name: "amount", ...layout_items_1.amountItem },
        ],
    },
    { name: "sourceDomain", binary: "uint", size: 4 },
    { name: "targetDomain", binary: "uint", size: 4 },
    { name: "nonce", binary: "uint", size: 8 },
    { name: "caller", ...layout_items_1.universalAddressItem },
    { name: "mintRecipient", ...layout_items_1.universalAddressItem },
];
//a future optimization would be to calculate the layout size from the layout itself
//  thought that does require implementing arithmetic on number literals, which is its very
//  own can of worms
const depositWithSizedLayoutPayload = (byteSize, layout) => [
    ...depositWithPayloadBase,
    { name: "payloadSize", binary: "uint", size: 2, custom: byteSize, omit: true },
    { name: "payload", binary: "object", layout }
];
exports.depositWithSizedLayoutPayload = depositWithSizedLayoutPayload;
const depositWithBytesPayload = (customPayload) => [
    ...depositWithPayloadBase,
    { name: "payload", binary: "bytes", lengthSize: 2, ...customPayload }
];
exports.depositWithBytesPayload = depositWithBytesPayload;
exports.namedPayloads = [
    ["DepositWithPayload", (0, exports.depositWithBytesPayload)({})],
    ["TransferRelay",
        (0, exports.depositWithSizedLayoutPayload)(1 + 3 * 32, [
            (0, layout_items_1.payloadIdItem)(1),
            { name: "targetRelayerFee", ...layout_items_1.amountItem },
            { name: "toNativeTokenAmount", ...layout_items_1.amountItem },
            { name: "targetRecipient", ...layout_items_1.universalAddressItem },
        ])
    ]
];
(0, vaa_1.registerPayloadTypes)("CCTP", exports.namedPayloads);
//# sourceMappingURL=connect.js.map